html {
    scroll-padding-top: 70px;
}

body {
    padding-top: 70px;
}

ul.nav .main {
    font-weight: bold;
}

.source-links {
    float: right;
}

.col-md-9 img {
  max-width: 100%;
}

pre, code {
    background: #e9ecef;
    color: #000;
    border: 1px solid rgba(0,0,0,0.125);
    border-radius: 0.25rem;
}

pre {
    padding: 0.5em;
}

code {
    padding: 1px 3px;
}

pre code {
    border: none;
    /* Override styles from hljs theme */
    background: transparent !important;
    padding: 0 !important;
}

a code {
    color: #008cba;
}

a:hover code {
    color: #00526e;
}

kbd {
    padding: 2px 4px;
    font-size: 90%;
    color: #fff;
    background-color: #333;
    border-radius: 3px;
    -webkit-box-shadow: inset 0 -1px 0 rgba(0,0,0,.25);
    box-shadow: inset 0 -1px 0 rgba(0,0,0,.25);
}

footer {
    margin-top: 30px;
    margin-bottom: 10px;
    text-align: center;
    font-weight: 200;
}

.modal-dialog {
    margin-top: 60px;
}

/*
 * Side navigation
 *
 * Scrollspy and affixed enhanced navigation to highlight sections and secondary
 * sections of docs content.
 */

.bs-sidebar.affix {
    position: -webkit-sticky;
    position: sticky;
    top: 80px;
}

.bs-sidebar.card {
    padding: 0;
}

.bs-sidebar > .card {
    background: #e9ecef !important;
}

/* First level of nav */
.bs-sidenav {
    padding-top:    10px;
    padding-bottom: 10px;
    border-radius: 5px;
    width: 100%;
}

/* All levels of nav */
.bs-sidebar .nav > li > a {
    display: block;
    padding: 5px 20px;
    z-index: 1;
}
.bs-sidebar .nav > li > a:hover,
.bs-sidebar .nav > li > a:focus {
    text-decoration: none;
    border-right: 1px solid;
}
.bs-sidebar .nav > .active > a,
.bs-sidebar .nav > .active:hover > a,
.bs-sidebar .nav > .active:focus > a {
    font-weight: bold;
    background-color: transparent;
    border-right: 1px solid;
}

/* Nav: second level (shown on .active) */
.bs-sidebar .nav .nav {
    display: none; /* Hide by default, but at >768px, show it */
    margin-bottom: 8px;
}
.bs-sidebar .nav .nav > li > a {
    padding-top:    3px;
    padding-bottom: 3px;
    padding-left: 30px;
    font-size: 90%;
}


.headerlink {
    display: none;
    padding-left: .5em;
}

h1:hover .headerlink, h2:hover .headerlink, h3:hover .headerlink, h4:hover .headerlink, h5:hover .headerlink, h6:hover .headerlink{
    display:inline-block;
}

/* display submenu relative to parent*/
.dropdown-submenu {
    position: relative;
}

/* sub menu stlye */
.dropdown-submenu>.dropdown-menu {
    top: 0;
    left: 100%;
    margin-top: 0px;
    margin-left: -1px;
}

/* display sub menu on hover*/
.dropdown-submenu:hover>.dropdown-menu {
    display: block;
}

/* little arrow */
.dropdown-submenu>a:after {
    display: block;
    content: " ";
    float: right;
    width: 0;
    height: 0;
    border-color: transparent;
    border-style: solid;
    border-width: 5px 0 5px 5px;
    border-left-color: #ccc;
    margin-top: 5px;
    margin-right: -10px;
}

/* little arrow of parent menu */
.dropdown-submenu:hover>a:after {
    border-left-color: #fff;
}
